@@ -34,11 +34,12 @@ LinkedAllocator::LinkedAllocator() : Conditional()
 LinkedObject *LinkedAllocator::get(void)
 {
     LinkedObject *node;
-    lock();
+
+    __AUTOLOCK__
+
     node = freelist;
     if(node)
         freelist = freelist->getNext();
-    unlock();
     return node;
 }
 
@@ -51,7 +52,8 @@ LinkedObject *LinkedAllocator::get(timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(!freelist && rtn) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -65,37 +67,36 @@ LinkedObject *LinkedAllocator::get(timeout_t timeout)
         if(node)
             freelist = freelist->getNext();
     }
-    unlock();
     return node;
 }
 
 void LinkedAllocator::release(LinkedObject *node)
 {
-    lock();
+    __AUTOLOCK__
+
     node->enlist(&freelist);
     signal();
-    unlock();
 }
 
-LinkedAllocator::operator bool()
+LinkedAllocator::operator bool() const
 {
     bool rtn = false;
 
-    lock();
+    __AUTOLOCK__
+
     if(freelist)
         rtn = true;
-    unlock();
     return rtn;
 }
 
-bool LinkedAllocator::operator!()
+bool LinkedAllocator::operator!() const
 {
     bool rtn = false;
 
-    lock();
+    __AUTOLOCK__
+
     if(!freelist)
         rtn = true;
-    unlock();
     return rtn;
 }
 
@@ -126,20 +127,20 @@ Buffer::~Buffer()
     buf = NULL;
 }
 
-unsigned Buffer::count(void)
+unsigned Buffer::count(void) const
 {
     unsigned bcount = 0;
 
-    lock();
+    __AUTOLOCK__
+
     if(tail > head)
         bcount = (unsigned)((size_t)(tail - head) / objsize);
     else if(head > tail)
         bcount = (unsigned)((((buf + bufsize) - head) + (tail - buf)) / objsize);
-    unlock();
     return bcount;
 }
 
-unsigned Buffer::size(void)
+unsigned Buffer::size(void) const
 {
     return bufsize / objsize;
 }
@@ -148,11 +149,11 @@ void *Buffer::get(void)
 {
     caddr_t dbuf;
 
-    lock();
+    __AUTOLOCK__
+
     while(!objcount)
         wait();
     dbuf = head;
-    unlock();
     return dbuf;
 }
 
@@ -165,16 +166,15 @@ void *Buffer::peek(unsigned offset)
 {
     caddr_t dbuf;
 
-    lock();
+    __AUTOLOCK__
+
     if(offset >= objcount) {
-        unlock();
         return invalid();
     }
 
     dbuf = head + (objsize * offset);
     if(dbuf >= buf + bufsize)
         dbuf -= bufsize;
-    unlock();
     return dbuf;
 }
 
@@ -209,7 +209,8 @@ void *Buffer::get(timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(!objcount && rtn) {
         if(timeout == Timer::inf)
             wait();
@@ -220,35 +221,37 @@ void *Buffer::get(timeout_t timeout)
     }
     if(objcount && rtn)
         dbuf = head;
-    unlock();
     return dbuf;
 }
 
 void Buffer::release(void)
 {
-    lock();
+    __AUTOLOCK__
+
     head += objsize;
     if(head >= buf + bufsize)
         head = buf;
     --objcount;
     signal();
-    unlock();
 }
 
 void Buffer::put(void *dbuf)
 {
     assert(dbuf != NULL);
 
-    lock();
+    __AUTOLOCK__
+
     while(objcount == limit)
         wait();
+
     memcpy(tail, dbuf, objsize);
     tail += objsize;
+
     if(tail >= (buf + bufsize))
         tail = buf;
+
     ++objcount;
     signal();
-    unlock();
 }
 
 bool Buffer::put(void *dbuf, timeout_t timeout)
@@ -261,7 +264,8 @@ bool Buffer::put(void *dbuf, timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(objcount == limit && rtn) {
         if(timeout == Timer::inf)
             wait();
@@ -278,30 +282,29 @@ bool Buffer::put(void *dbuf, timeout_t timeout)
         ++objcount;
         signal();
     }
-    unlock();
     return rtn;
 }
 
 
-Buffer::operator bool()
+Buffer::operator bool() const
 {
     bool rtn = false;
 
-    lock();
+    __AUTOLOCK__
+
     if(buf && head != tail)
         rtn = true;
-    unlock();
     return rtn;
 }
 
-bool Buffer::operator!()
+bool Buffer::operator!() const
 {
     bool rtn = false;
 
-    lock();
+    __AUTOLOCK__
+
     if(!buf || head == tail)
         rtn = true;
-    unlock();
     return rtn;
 }
 
@@ -354,7 +357,9 @@ bool Queue::remove(ObjectProtocol *o)
 
     bool rtn = false;
     linked_pointer<member> node;
-    lock();
+
+    __AUTOLOCK__
+
     node = begin();
     while(node) {
         if(node->object == o)
@@ -368,7 +373,6 @@ bool Queue::remove(ObjectProtocol *o)
         node->delist(this);
         node->LinkedObject::enlist(&freelist);
     }
-    unlock();
     return rtn;
 }
 
@@ -382,7 +386,8 @@ ObjectProtocol *Queue::lifo(timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(!tail && rtn) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -400,7 +405,6 @@ ObjectProtocol *Queue::lifo(timeout_t timeout)
     }
     if(rtn)
         signal();
-    unlock();
     return obj;
 }
 
@@ -414,7 +418,8 @@ ObjectProtocol *Queue::fifo(timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(rtn && !head) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -435,7 +440,6 @@ ObjectProtocol *Queue::fifo(timeout_t timeout)
     }
     if(rtn)
         signal();
-    unlock();
     return obj;
 }
 
@@ -449,7 +453,7 @@ ObjectProtocol *Queue::get(unsigned back)
     linked_pointer<member> node;
     ObjectProtocol *obj;
 
-    lock();
+    __AUTOLOCK__
 
     node = begin();
 
@@ -463,7 +467,6 @@ ObjectProtocol *Queue::get(unsigned back)
 
     } while(back-- > 0);
 
-    unlock();
     return obj;
 }
 
@@ -478,7 +481,8 @@ bool Queue::post(ObjectProtocol *object, timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(rtn && limit && used == limit) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -489,7 +493,6 @@ bool Queue::post(ObjectProtocol *object, timeout_t timeout)
     }
 
     if(!rtn) {
-        unlock();
         return false;
     }
 
@@ -506,16 +509,15 @@ bool Queue::post(ObjectProtocol *object, timeout_t timeout)
             new member(this, object);
     }
     signal();
-    unlock();
     return true;
 }
 
-size_t Queue::count(void)
+size_t Queue::count(void) const
 {
     size_t qcount;
-    lock();
+
+    __AUTOLOCK__
     qcount = used;
-    unlock();
     return qcount;
 }
 
@@ -569,7 +571,9 @@ bool Stack::remove(ObjectProtocol *o)
 
     bool rtn = false;
     linked_pointer<member> node;
-    lock();
+
+    __AUTOLOCK__
+
     node = static_cast<member*>(usedlist);
     while(node) {
         if(node->object == o)
@@ -583,7 +587,6 @@ bool Stack::remove(ObjectProtocol *o)
         node->delist(&usedlist);
         node->enlist(&freelist);
     }
-    unlock();
     return rtn;
 }
 
@@ -597,7 +600,8 @@ ObjectProtocol *Stack::get(unsigned back)
     linked_pointer<member> node;
     ObjectProtocol *obj;
 
-    lock();
+    __AUTOLOCK__
+
     node = usedlist;
 
     do {
@@ -610,7 +614,6 @@ ObjectProtocol *Stack::get(unsigned back)
 
     } while(back-- > 0);
 
-    unlock();
     return obj;
 }
 
@@ -624,7 +627,8 @@ const ObjectProtocol *Stack::peek(timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(rtn && !usedlist) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -633,8 +637,8 @@ const ObjectProtocol *Stack::peek(timeout_t timeout)
         else
             rtn = false;
     }
+
     if(!rtn) {
-        unlock();
         return NULL;
     }
     if(usedlist) {
@@ -643,7 +647,6 @@ const ObjectProtocol *Stack::peek(timeout_t timeout)
     }
     if(rtn)
         signal();
-    unlock();
     return obj;
 }
 
@@ -657,7 +660,8 @@ ObjectProtocol *Stack::pull(timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(rtn && !usedlist) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -667,7 +671,6 @@ ObjectProtocol *Stack::pull(timeout_t timeout)
             rtn = false;
     }
     if(!rtn) {
-        unlock();
         return NULL;
     }
     if(usedlist) {
@@ -678,7 +681,6 @@ ObjectProtocol *Stack::pull(timeout_t timeout)
     }
     if(rtn)
         signal();
-    unlock();
     return obj;
 }
 
@@ -693,7 +695,8 @@ bool Stack::push(ObjectProtocol *object, timeout_t timeout)
     if(timeout && timeout != Timer::inf)
         set(&ts, timeout);
 
-    lock();
+    __AUTOLOCK__
+
     while(rtn && limit && used == limit) {
         if(timeout == Timer::inf)
             Conditional::wait();
@@ -704,7 +707,6 @@ bool Stack::push(ObjectProtocol *object, timeout_t timeout)
     }
 
     if(!rtn) {
-        unlock();
         return false;
     }
 
@@ -723,16 +725,16 @@ bool Stack::push(ObjectProtocol *object, timeout_t timeout)
             new member(this, object);
     }
     signal();
-    unlock();
     return true;
 }
 
-size_t Stack::count(void)
+size_t Stack::count(void) const
 {
     size_t scount;
-    lock();
+
+    __AUTOLOCK__
+
     scount = used;
-    unlock();
     return scount;
 }
 
