@@ -49,6 +49,10 @@ extern "C" {
  */
 __EXPORT void cpr_runtime_error(const char *text);
 
+extern "C" __EXPORT void *cpr_newp(void **handle, size_t size);
+
+extern "C" __EXPORT void cpr_freep(void **handle);
+
 /**
  * Portable memory allocation helper function.  Handles out of heap error
  * as a runtime error.
@@ -186,4 +190,14 @@ extern "C" {
     __EXPORT void msb_setlong(uint8_t *b, uint32_t v);
 }
 
+template <typename T>
+T *newp(T **handle) {
+    return (T*)cpr_newp(handle, sizeof(T));
+}
+
+template <typename T>
+void freep(T **handle) {
+    cpr_freep(handle);
+}
+
 #endif
