@@ -21,6 +21,8 @@
 #include <fcntl.h>
 #endif
 
+namespace ucommon {
+
 void Random::seed(void)
 {
     time_t now;
@@ -49,7 +51,7 @@ bool Random::seed(const unsigned char *buf, size_t size)
 size_t Random::key(unsigned char *buf, size_t size)
 {
 #ifdef  _MSWINDOWS_
-    if((_handle != (HCRYPTPROV)NULL) && CryptGenRandom(_handle, size, buf))
+    if((__handle != (HCRYPTPROV)NULL) && CryptGenRandom(__handle, size, buf))
         return size;
     return 0;
 #else
@@ -106,3 +108,4 @@ bool Random::status(void)
 #endif
 }
 
+} // namespace ucommon
