@@ -17,10 +17,9 @@
 
 #include "local.h"
 
+namespace ucommon {
 #ifdef  _MSWINDOWS_
-NAMESPACE_LOCAL
-HCRYPTPROV _handle = (HCRYPTPROV)NULL;
-END_NAMESPACE
+HCRYPTPROV __handle = (HCRYPTPROV)NULL;
 #endif
 
 secure::~secure()
@@ -38,17 +37,17 @@ bool secure::init(void)
     Socket::init();
 
 #ifdef  _MSWINDOWS_
-    if(_handle != (HCRYPTPROV)NULL)
+    if(__handle != (HCRYPTPROV)NULL)
         return false;
 
-    if(CryptAcquireContext(&_handle, NULL, NULL, PROV_RSA_FULL, 0))
+    if(CryptAcquireContext(&__handle, NULL, NULL, PROV_RSA_FULL, 0))
         return false;
     if(GetLastError() == (DWORD)NTE_BAD_KEYSET) {
-        if(CryptAcquireContext(&_handle, NULL, NULL, PROV_RSA_FULL, CRYPT_NEWKEYSET))
+        if(CryptAcquireContext(&__handle, NULL, NULL, PROV_RSA_FULL, CRYPT_NEWKEYSET))
             return false;
     }
 
-    _handle = (HCRYPTPROV)NULL;
+    __handle = (HCRYPTPROV)NULL;
 #endif
 
     return false;
@@ -68,3 +67,4 @@ void secure::cipher(secure *context, const char *ciphers)
 {
 }
 
+} // namespace ucommon
